// 订单相关
import { request } from "@/lib/service"
import { baseUrl } from '@/config'
 
/**
 * @desc 提交订单前数据确认接口
 * buy_type * 购买类型：0默认加入购物车 1立即购买
 * cart_ids 选中的购物车IDs，多个则使用逗号分隔(buy_type=0时必填)
 * sku_ids SKUIDs，多个则使用逗号分隔(buy_type=1时必填)
 * cart_numbers 购买数量s，多个则使用逗号分隔(buy_type=1时必填)
 */
export function preConfirmOrderData(params) {
	return request({
		url: 'zsxcx/orderDetail.htm',
		method: 'post',
		data: params,
		needMask: true
	})
}

/**
 * @desc 提交订单
 * look up docs
 */
export function confirmOrder(params) {
	return request({
		url: 'zsxcx/orderInfoXcx.htm',
		method: 'post',
		data: params,
		needMask: true
	})
}

/**
 * @desc 获取订单列表
 */
export function orderList(params) {
	return request({
		url: 'zsxcx/orderXcx.htm',
		method: 'post',
		data: params
	})
}

/**
 * @desc 订单详情
 */
export function orderDetail(order_sn) {
	return request({
		url: 'zsxcx/snapshotXcx.htm',
		method: 'post',
		data: {
			order_sn
		},
		needMask: true
	})
}


/**
 * @desc 提醒发货接口
 */
export function remindOrder({order_id, order_sn}) {
	return request({
		url: 'zsxcx/remindXcx.htm',
		method: 'post',
		data: {
			order_sn,
			order_id
		},
		needMask: true
	})
}


/**
 * @desc 取消订单
 */
export function cancelDetail1(order_sn) {
	return request({
		url: 'zsxcx/orderCancelXcx.htm',
		method: 'post',
		data: {
			order_sn
		},
		needMask: true
	})
}

/**
 * @desc 确认收货
 */
export function recieveOrder(order_sn) {
	return request({
		url: 'zsxcx/orderConfirmXcx.htm',
		method: 'post',
		data: {
			order_sn
		}
	})
}